/*jslint browser: true, vars:true*/
/*global define*/
define([
    'testsuite/qunit',
    'jquery',
    'de_epages/design/ui/cookiemessage',
    '$ready!'
], function (QUnit, $) {

    'use strict';

    QUnit.module('de_epages/design/ui/cookiemessage', {
        setup: function () {
            // delete all cookies
            document.cookie = 'epagescookielawcookie=';
        }
    });

    var message = 'We use cookies on our site!',
        link = '/privacypolicy',
        linktext = 'Privacy Policy',
        options = {
            'message': message,
            'link': link,
            'linktext': linktext
        },
        parentClass = 'message-bar-parent';

    QUnit.test("prototype methods", 5, function () {
        // Check prototype methods.
        $.each(['_create', 'isAccepted', 'accept', 'render', 'destroy'], function (i, fn) {

            QUnit.strictEqual($.isFunction($.ui.designUiCookiemessage.prototype[fn]),
                true,
                '$.isFunction(' + fn + ')');

        });
    });

    QUnit.test('Cookie message apears on first visit', 9, function () {
        var $element = $('body');

        // create widget
        $element.designUiCookiemessage(options);

        // test UI
        QUnit.ok($('.message-bar.message-cookies:visible').length === 1, 'Cookie message is visible');
        QUnit.ok($('.message-bar-button').length === 1, 'Message bar contains close button.');
        QUnit.ok($('body').hasClass(parentClass), 'Parent element of cookie message bar has the class "'+ parentClass + '"');

        // click close button
        $('.message-bar-button').trigger('click');

        // test UI
        QUnit.ok($('.message-bar.message-cookies:visible').length === 0, 'Cookie message hides when clicking the button');
        QUnit.ok(!$('body').hasClass(parentClass), 'Parent element of cookie message bar has not the class "'+ parentClass + '"');

        // check if cookie exists
        QUnit.equal(document.cookie, "epagescookielawcookie=1", 'Cookie was set after clicking the button');

        // destroy widget
        $element.designUiCookiemessage('destroy');
        // create widget
        $element.designUiCookiemessage(options);

        // test UI => message bar is not displayed if cookie is set
        QUnit.ok($('.message-bar.message-cookies:visible').length === 0, 'Cookie message doesn\'t show up again');

        // delete cookie
        document.cookie = 'epagescookielawcookie=';

        // destroy widget
        $element.designUiCookiemessage('destroy');
        // create widget
        $element.designUiCookiemessage(options);

        // test UI => message bar is displayed again after cookie was set
        QUnit.ok($('.message-bar.message-cookies:visible').length === 1, 'Cookie message shown up again after deleting the cookie');

        // cookie is set when preAccepted is true
        options.preAccepted = true;

        // destroy widget
        $element.designUiCookiemessage('destroy');

        // create widget
        $element.designUiCookiemessage(options);

        QUnit.ok($('.message-bar.message-cookies:visible').length === 0, 'Cookie message is not shown with preAccepted setted');
    });
});